@@ -1,6 +1,6 @@
 #include <pygobject.h>
 
-void trayicon_register_classes (PyObject *d);
+void gtkwidgets_register_classes (PyObject *d);
 extern PyMethodDef gtkwidgets_functions[];
  
 DL_EXPORT(void)
