@@ -914,7 +914,7 @@ char *oauth_body_hash_file(char *filename) {
   fclose(F);
   len=0;
   md=(unsigned char*) calloc(EVP_MD_size(EVP_sha1()),sizeof(unsigned char));
-  EVP_DigestFinal(&ctx, md, &len);
+  EVP_DigestFinal(&ctx, md, (unsigned int *) &len);
   EVP_MD_CTX_cleanup(&ctx);
   return oauth_body_hash_encode(len, md);
 }
@@ -927,7 +927,7 @@ char *oauth_body_hash_data(size_t length, const char *data) {
   EVP_MD_CTX_init(&ctx);
   EVP_DigestInit(&ctx,EVP_sha1());
   EVP_DigestUpdate(&ctx, data, length);
-  EVP_DigestFinal(&ctx, md, &len);
+  EVP_DigestFinal(&ctx, md, (unsigned int *) &len);
   EVP_MD_CTX_cleanup(&ctx);
   return oauth_body_hash_encode(len, md);
 }
