@@ -1221,6 +1221,34 @@ _u1_music_store_rescan_purchased_folder (U1MusicStore *music_store)
 					 music_store);
 }
 
+static gboolean
+_u1_music_store_delayed_init (gpointer user_data)
+{
+	U1MusicStore *music_store = U1_MUSIC_STORE (user_data);
+	SyncdaemonFolderInfo *folder_info;
+
+	/* Figure out if the Purchased Music folder is subscribed */
+	folder_info = syncdaemon_daemon_get_folder_info (music_store->priv->syncdaemon, u1_music_store_get_library_location (music_store));
+	music_store->priv->folder_subscribed = syncdaemon_folder_info_get_subscribed (folder_info);
+
+	/* Create a hidden progress bar */
+	music_store->priv->progress = gtk_progress_bar_new ();
+	
+	g_signal_connect (G_OBJECT (music_store->priv->web_viewer), "notify",
+			  G_CALLBACK (viewer_property_changed_cb), music_store);
+
+	/* And load the real store in the background */
+	music_store->priv->idle_cb = g_idle_add ((GSourceFunc) load_real_store_cb, music_store);
+
+	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->alertbar, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->scroll, TRUE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (music_store), music_store->priv->progress, FALSE, FALSE, 0);
+
+	_u1_music_store_rescan_purchased_folder (music_store);
+
+	return FALSE;
+}
+
 static void
 u1_music_store_init (U1MusicStore *music_store)
 {
@@ -1228,7 +1256,6 @@ u1_music_store_init (U1MusicStore *music_store)
 	const gchar *url_to_use;
 	SoupSession *session;
 	GtkWidget *alert_icon;
-	SyncdaemonFolderInfo *folder_info;
 
 	if (!g_thread_get_initialized ())
 		g_thread_init (NULL);
@@ -1343,24 +1370,8 @@ u1_music_store_init (U1MusicStore *music_store)
 	g_signal_connect (G_OBJECT (music_store->priv->subscribe_btn), "clicked",
 			  G_CALLBACK (subscribe_purchased_folder), music_store);
 
-	/* Figure out if the Purchased Music folder is subscribed */
-	folder_info = syncdaemon_daemon_get_folder_info (music_store->priv->syncdaemon, u1_music_store_get_library_location (music_store));
-	music_store->priv->folder_subscribed = syncdaemon_folder_info_get_subscribed (folder_info);
-
-	/* Create a hidden progress bar */
-	music_store->priv->progress = gtk_progress_bar_new ();
-	
-	g_signal_connect (G_OBJECT (music_store->priv->web_viewer), "notify",
-			  G_CALLBACK (viewer_property_changed_cb), music_store);
-
-	/* And load the real store in the background */
-	music_store->priv->idle_cb = g_idle_add ((GSourceFunc) load_real_store_cb, music_store);
-
-	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->alertbar, FALSE, FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->scroll, TRUE, TRUE, 0);
-	gtk_box_pack_end (GTK_BOX (music_store), music_store->priv->progress, FALSE, FALSE, 0);
-
-	_u1_music_store_rescan_purchased_folder (music_store);
+	g_timeout_add_seconds(10, (GSourceFunc) _u1_music_store_delayed_init,
+			      music_store);
 }
 
 /**
